# -*- coding: UTF-8 -*-
"""
Hive Posts Scutineer
~~~~~~~~~~~~~~~~

Performance and quality analytics on Hive Posts.

"""

__version__ = "1.3.11"
from .scrutineer import Scrutineer
from .scrutineer import get_keywords
from .scrutineer import get_bigrams


__all__ = ["scrutineer"]
